@@ -5,7 +5,7 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2022
-;; Version: 1.8
+;; Version: 1.9
 ;; Package-Requires: ((emacs "28.1") (org "9.5") (compat "30"))
 ;; URL: https://github.com/minad/org-modern
 ;; Keywords: outlines, hypermedia, text
@@ -593,7 +593,7 @@ whole buffer; otherwise, for the line at point."
       (when separator
         (when (numberp org-modern-table-horizontal)
           (add-face-text-property tbeg tend org-modern--table-overline 'append)
-          (add-face-text-property beg (1+ end) `(:height ,org-modern-table-horizontal) 'append))
+          (add-face-text-property beg (min (1+ end) (point-max)) `(:height ,org-modern-table-horizontal) 'append))
         (while (re-search-forward "[^|+]+" tend 'noerror)
           (let ((a (match-beginning 0))
                 (b (match-end 0)))
@@ -742,7 +742,7 @@ whole buffer; otherwise, for the line at point."
      `(("^[ \t]*-\\{5,\\}$" 0
         '(face org-modern-horizontal-rule display
                ,(if (eq org-modern-horizontal-rule t)
-                    '(space :width text)
+                    '(space :width (- text 1))
                   org-modern-horizontal-rule)))))
    (when org-modern-table
      '(("^[ \t]*\\(|.*|\\)[ \t]*$" (0 (org-modern--table)))))
